diff avformat.h @ 3334:7a823a401282 libavformat

Pass time_base as argument to new_chapter() as well. This fixes the wrong timebase the matroska demuxer had after my previous commits. Maybe we should reduce new_chapter() to just (AVFormatContext, int id) ?
author michael
date Fri, 23 May 2008 18:15:13 +0000
parents 8bec7ae8f0bb
children 7a0230981402
line wrap: on
line diff
--- a/avformat.h	Fri May 23 17:56:45 2008 +0000
+++ b/avformat.h	Fri May 23 18:15:13 2008 +0000
@@ -776,13 +776,13 @@
  *
  * @param s media file handle
  * @param id unique id for this chapter
  * @param start chapter start time in AV_TIME_BASE units
  * @param end chapter end time in AV_TIME_BASE units
  * @param title chapter title
  *
  * @return AVChapter or NULL if error.
  */
-AVChapter *ff_new_chapter(AVFormatContext *s, int id, int64_t start, int64_t end, const char *title);
+AVChapter *ff_new_chapter(AVFormatContext *s, int id, AVRational time_base, int64_t start, int64_t end, const char *title);
 
 /**
  * Set the pts for a given stream.
@@ -776,13 +776,13 @@
  * @param s media file handle
  * @param id unique id for this chapter
- * @param start chapter start time in AV_TIME_BASE units
- * @param end chapter end time in AV_TIME_BASE units
+ * @param start chapter start time in time_base units
+ * @param end chapter end time in time_base units
  * @param title chapter title
  *